Documentation
¶
Index ¶
- type Falcon
- type ModelOption
- type ModelOptions
- type PredictOption
- func SetBatch(size int) PredictOption
- func SetFrequencyPenalty(fp float64) PredictOption
- func SetLogitBias(lb string) PredictOption
- func SetMemoryMap(b bool) PredictOption
- func SetMirostat(m int) PredictOption
- func SetMirostatETA(me float64) PredictOption
- func SetMirostatTAU(mt float64) PredictOption
- func SetMlock(b bool) PredictOption
- func SetNKeep(n int) PredictOption
- func SetPathPromptCache(f string) PredictOption
- func SetPenalizeNL(pnl bool) PredictOption
- func SetPenalty(penalty float64) PredictOption
- func SetPredictionMainGPU(maingpu string) PredictOption
- func SetPredictionTensorSplit(maingpu string) PredictOption
- func SetPresencePenalty(pp float64) PredictOption
- func SetRepeat(repeat int) PredictOption
- func SetSeed(seed int) PredictOption
- func SetStopWords(stop ...string) PredictOption
- func SetTailFreeSamplingZ(tfz float64) PredictOption
- func SetTemperature(temp float64) PredictOption
- func SetThreads(threads int) PredictOption
- func SetTokenCallback(fn func(string) bool) PredictOption
- func SetTokens(tokens int) PredictOption
- func SetTopK(topk int) PredictOption
- func SetTopP(topp float64) PredictOption
- func SetTypicalP(tp float64) PredictOption
- type PredictOptions
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Falcon ¶
type Falcon struct {
// contains filtered or unexported fields
}
func (*Falcon) Predict ¶
func (l *Falcon) Predict(text string, opts ...PredictOption) (string, error)
func (*Falcon) SetTokenCallback ¶
SetTokenCallback registers a callback for the individual tokens created when running Predict. It will be called once for each token. The callback shall return true as long as the model should continue predicting the next token. When the callback returns false the predictor will return. The tokens are just converted into Go strings, they are not trimmed or otherwise changed. Also the tokens may not be valid UTF-8. Pass in nil to remove a callback.
It is save to call this method while a prediction is running.
type ModelOption ¶
type ModelOption func(p *ModelOptions)
var EnableEmbeddings ModelOption = func(p *ModelOptions) { p.Embeddings = true }
var EnableF16Memory ModelOption = func(p *ModelOptions) { p.F16Memory = true }
var EnableMLock ModelOption = func(p *ModelOptions) { p.MLock = true }
var VocabOnly ModelOption = func(p *ModelOptions) { p.VocabOnly = true }
func SetGPULayers ¶
func SetGPULayers(n int) ModelOption
SetGPULayers sets the number of GPU layers to use to offload computation
func SetModelSeed ¶
func SetModelSeed(c int) ModelOption
func SetTensorSplit ¶
func SetTensorSplit(maingpu string) ModelOption
Set sets the tensor split for the GPU
type ModelOptions ¶
type ModelOptions struct {
ContextSize int
Seed int
NBatch int
F16Memory bool
MLock bool
MMap bool
VocabOnly bool
Embeddings bool
NGPULayers int
MainGPU string
TensorSplit string
}
var DefaultModelOptions ModelOptions = ModelOptions{ ContextSize: 512, Seed: 0, F16Memory: false, MLock: false, Embeddings: false, MMap: true, }
func NewModelOptions ¶
func NewModelOptions(opts ...ModelOption) ModelOptions
Create a new PredictOptions object with the given options.
type PredictOption ¶
type PredictOption func(p *PredictOptions)
var Debug PredictOption = func(p *PredictOptions) { p.DebugMode = true }
var EnableF16KV PredictOption = func(p *PredictOptions) { p.F16KV = true }
var EnablePromptCacheAll PredictOption = func(p *PredictOptions) { p.PromptCacheAll = true }
var EnablePromptCacheRO PredictOption = func(p *PredictOptions) { p.PromptCacheRO = true }
var IgnoreEOS PredictOption = func(p *PredictOptions) { p.IgnoreEOS = true }
func SetFrequencyPenalty ¶
func SetFrequencyPenalty(fp float64) PredictOption
SetFrequencyPenalty sets the frequency penalty parameter, freq_penalty.
func SetLogitBias ¶
func SetLogitBias(lb string) PredictOption
SetLogitBias sets the logit bias parameter.
func SetMirostatETA ¶
func SetMirostatETA(me float64) PredictOption
SetMirostatETA sets the mirostat ETA parameter.
func SetMirostatTAU ¶
func SetMirostatTAU(mt float64) PredictOption
SetMirostatTAU sets the mirostat TAU parameter.
func SetNKeep ¶
func SetNKeep(n int) PredictOption
SetKeep sets the number of tokens from initial prompt to keep.
func SetPathPromptCache ¶
func SetPathPromptCache(f string) PredictOption
SetPathPromptCache sets the session file to store the prompt cache.
func SetPenalizeNL ¶
func SetPenalizeNL(pnl bool) PredictOption
SetPenalizeNL sets whether to penalize newlines or not.
func SetPenalty ¶
func SetPenalty(penalty float64) PredictOption
SetPenalty sets the repetition penalty for text generation.
func SetPredictionMainGPU ¶
func SetPredictionMainGPU(maingpu string) PredictOption
SetPredictionMainGPU sets the main_gpu
func SetPredictionTensorSplit ¶
func SetPredictionTensorSplit(maingpu string) PredictOption
SetPredictionTensorSplit sets the tensor split for the GPU
func SetPresencePenalty ¶
func SetPresencePenalty(pp float64) PredictOption
SetPresencePenalty sets the presence penalty parameter, presence_penalty.
func SetRepeat ¶
func SetRepeat(repeat int) PredictOption
SetRepeat sets the number of times to repeat text generation.
func SetSeed ¶
func SetSeed(seed int) PredictOption
SetSeed sets the random seed for sampling text generation.
func SetStopWords ¶
func SetStopWords(stop ...string) PredictOption
SetStopWords sets the prompts that will stop predictions.
func SetTailFreeSamplingZ ¶
func SetTailFreeSamplingZ(tfz float64) PredictOption
SetTailFreeSamplingZ sets the tail free sampling, parameter z.
func SetTemperature ¶
func SetTemperature(temp float64) PredictOption
SetTemperature sets the temperature value for text generation.
func SetThreads ¶
func SetThreads(threads int) PredictOption
SetThreads sets the number of threads to use for text generation.
func SetTokenCallback ¶
func SetTokenCallback(fn func(string) bool) PredictOption
SetTokenCallback sets the prompts that will stop predictions.
func SetTokens ¶
func SetTokens(tokens int) PredictOption
SetTokens sets the number of tokens to generate.
func SetTopP ¶
func SetTopP(topp float64) PredictOption
SetTopP sets the value for nucleus sampling.
func SetTypicalP ¶
func SetTypicalP(tp float64) PredictOption
SetTypicalP sets the typicality parameter, p_typical.
type PredictOptions ¶
type PredictOptions struct {
Seed, Threads, Tokens, TopK, Repeat, Batch, NKeep int
TopP, Temperature, Penalty float64
F16KV bool
DebugMode bool
StopPrompts string
IgnoreEOS bool
TailFreeSamplingZ float64
TypicalP float64
FrequencyPenalty float64
PresencePenalty float64
Mirostat int
MirostatETA float64
MirostatTAU float64
PenalizeNL bool
LogitBias string
TokenCallback func(string) bool
PathPromptCache string
MLock, MMap, PromptCacheAll bool
PromptCacheRO bool
MainGPU string
TensorSplit string
}
var DefaultOptions PredictOptions = PredictOptions{ Seed: -1, Threads: 4, Tokens: 128, Penalty: 1.1, Repeat: 64, Batch: 512, NKeep: 0, TopK: 40, TopP: 0.95, TailFreeSamplingZ: 1.0, TypicalP: 1.0, Temperature: 0.8, FrequencyPenalty: 0.0, PresencePenalty: 0.0, Mirostat: 0, MirostatTAU: 5.0, MirostatETA: 0.1, MMap: true, }
func NewPredictOptions ¶
func NewPredictOptions(opts ...PredictOption) PredictOptions
Create a new PredictOptions object with the given options.